pub struct SongMedia {
pub native_uri: Option<String>,
pub attribution: Option<String>,
pub provider: String,
pub start: Option<u32>,
pub media_type: String,
pub url: String,
}Fields
native_uri: Option<String>Spotify path of the song with : instead /, weird.
attribution: Option<String>Soundcloud username.
provider: StringThe song host provider youtube, soundcloud or spotify.
start: Option<u32>Youtube position of the video that starts the music.
media_type: StringMedia type video or audio
url: StringThe url of the song in the media host.