pub struct Album {Show 21 fields
pub api_path: String,
pub comment_count: Option<u32>,
pub cover_art_thumbnail_url: Option<String>,
pub cover_art_url: String,
pub custom_header_image_url: Option<String>,
pub full_title: String,
pub header_image_url: Option<String>,
pub id: u32,
pub lock_state: Option<String>,
pub name: String,
pub name_with_artist: Option<String>,
pub pyongs_count: Option<u32>,
pub release_date: Option<String>,
pub release_date_components: Option<Date>,
pub url: String,
pub current_user_metadata: Option<UserMetadata>,
pub album_pageviews: Option<u32>,
pub artist: Artist,
pub cover_arts: Option<Vec<CoverArt>>,
pub description_annotation: Option<Referent>,
pub song_performances: Option<Vec<SongPerformance>>,
}Fields
api_path: StringPath of the API.
comment_count: Option<u32>Number of comments.
Only in
get_album
cover_art_thumbnail_url: Option<String>Cover art thumbnail if the album.
Only with
user-corelevel token
cover_art_url: StringCover art of the album.
custom_header_image_url: Option<String>Custom header image.
Only in
get_album
full_title: StringFull album title is: “name by author”.
header_image_url: Option<String>Header image.
Only in
get_album
id: u32Id of the album.
lock_state: Option<String>Only in
get_album
name: StringName of the album.
name_with_artist: Option<String>Name with artist in {album name} (artist: {artist name})
Only with
user-corelevel token
pyongs_count: Option<u32>Number of pyongs in this album.
Only in
get_album
release_date: Option<String>Release date of the album in ISO 8601 date format.
Only in
get_album
release_date_components: Option<Date>Release date of the album in struct format Date.
Only in
get_albumor withuser-corelevel token
url: StringUrl of the album page.
current_user_metadata: Option<UserMetadata>Current user metadata have all the permissions of the user to vote, edit etc. and some others stuffs.
Only in
get_album
album_pageviews: Option<u32>Number of views in the album page.
Only in
get_album
artist: ArtistAlbum artist.
cover_arts: Option<Vec<CoverArt>>All cover arts of the album.
Only in
get_album
description_annotation: Option<Referent>Annotations in this album.
Only in
get_album
song_performances: Option<Vec<SongPerformance>>All the people who worked on this album.
Only in
get_album